searchNodes=[{"ref":"Relate.html","title":"Relate","module":"Relate","type":"module","doc":"Relate implements relational operators on Elixir enumerables. Join functions take two enumerables containing objects as well as one or two arguments to specify how the value to use as a basis for joining will be determined. If either fki1 or fki2 are functions, the function will be called with the object as an argument on e1 or e2, respectively. If the value is an atom, the object will be treated as a map and the join value will be the value of the key associated with the atom. If the value is a non-negative integer, the object will be treated as a tuple and the value will be treated as an index into it. If fki2 is not specified or is nil or false, the same accessor will be used on both e1 and e2."},{"ref":"Relate.html#inner_join/4","title":"Relate.inner_join/4","module":"Relate","type":"function","doc":"Return an enumerable of tuples containing all elements of e1 and e2 which yield the same value when fki1 and fki2 are applied, respectively. If fki2 is nil or false, fki1 will be used to make comparisons on both enumerables. Examples iex&gt; Relate.inner_join([%{k: 0, v: &quot;zero&quot;}, %{k: 1, v: &quot;one&quot;}], ...&gt; [%{k: 1, v: &quot;i&quot;}, %{k: 2, v: &quot;ii&quot;}], ...&gt; :k, :k) [{%{k: 1, v: &quot;one&quot;}, %{k: 1, v: &quot;i&quot;}}] iex&gt; Relate.inner_join([%{k: 0, v: &quot;zero&quot;}, %{k: 1, v: &quot;one&quot;}], ...&gt; [%{k: 1, v: &quot;i&quot;}, %{k: 2, v: &quot;ii&quot;}], ...&gt; :k) # NOTE: only one key function [{%{k: 1, v: &quot;one&quot;}, %{k: 1, v: &quot;i&quot;}}]"},{"ref":"Relate.html#left_join/4","title":"Relate.left_join/4","module":"Relate","type":"function","doc":"Return an enumerable of tuples containing all elements of e1 and e2 which yield the same value when fki1 and fki2 are applied, respectively. If fki2 is nil or false, fki1 will be used to make comparisons on both enumerables. Additionally, a tuple of the form {i, nil} will be returned for every element of e1 that did not match on any element in e2. Examples iex&gt; Relate.left_join([%{k: 0, v: &quot;zero&quot;}, %{k: 1, v: &quot;one&quot;}], ...&gt; [%{k: 1, v: &quot;i&quot;}, %{k: 2, v: &quot;ii&quot;}], ...&gt; :k, :k) [{%{k: 0, v: &quot;zero&quot;}, nil}, {%{k: 1, v: &quot;one&quot;}, %{k: 1, v: &quot;i&quot;}}] iex&gt; Relate.left_join([%{k: 0, v: &quot;zero&quot;}, %{k: 1, v: &quot;one&quot;}], ...&gt; [%{k: 1, v: &quot;i&quot;}, %{k: 2, v: &quot;ii&quot;}], ...&gt; :k) # NOTE: only one key function [{%{k: 0, v: &quot;zero&quot;}, nil}, {%{k: 1, v: &quot;one&quot;}, %{k: 1, v: &quot;i&quot;}}]"},{"ref":"Relate.html#outer_join/4","title":"Relate.outer_join/4","module":"Relate","type":"function","doc":"Return an enumerable of tuples containing all elements of e1 and e2 which yield the same value when fki1 and fki2 are applied, respectively. If fki2 is nil or false, fki1 will be used to make comparisons on both enumerables. Additionally, a tuple of the form {nil, i} or {i, nil} will be returned for every element of e2 that did not match on any element in e1 and vice-versa. Examples iex&gt; Relate.outer_join([%{k: 0, v: &quot;zero&quot;}, %{k: 1, v: &quot;one&quot;}], ...&gt; [%{k: 1, v: &quot;i&quot;}, %{k: 2, v: &quot;ii&quot;}], ...&gt; :k, :k) [{%{k: 0, v: &quot;zero&quot;}, nil}, {%{k: 1, v: &quot;one&quot;}, %{k: 1, v: &quot;i&quot;}}, {nil, %{k: 2, v: &quot;ii&quot;}}] iex&gt; Relate.outer_join([%{k: 0, v: &quot;zero&quot;}, %{k: 1, v: &quot;one&quot;}], ...&gt; [%{k: 1, v: &quot;i&quot;}, %{k: 2, v: &quot;ii&quot;}], ...&gt; :k) # NOTE: only one key function [{%{k: 0, v: &quot;zero&quot;}, nil}, {%{k: 1, v: &quot;one&quot;}, %{k: 1, v: &quot;i&quot;}}, {nil, %{k: 2, v: &quot;ii&quot;}}]"},{"ref":"Relate.html#right_join/4","title":"Relate.right_join/4","module":"Relate","type":"function","doc":"Return an enumerable of tuples containing all elements of e1 and e2 which yield the same value when fki1 and fki2 are applied, respectively. If fki2 is nil or false, fki1 will be used to make comparisons on both enumerables. Additionally, a tuple of the form {nil, i} will be returned for every element of e2 that did not match on any element in e1. Examples iex&gt; Relate.right_join([%{k: 0, v: &quot;zero&quot;}, %{k: 1, v: &quot;one&quot;}], ...&gt; [%{k: 1, v: &quot;i&quot;}, %{k: 2, v: &quot;ii&quot;}], ...&gt; :k, :k) [{%{k: 1, v: &quot;one&quot;}, %{k: 1, v: &quot;i&quot;}}, {nil, %{k: 2, v: &quot;ii&quot;}}] iex&gt; Relate.right_join([%{k: 0, v: &quot;zero&quot;}, %{k: 1, v: &quot;one&quot;}], ...&gt; [%{k: 1, v: &quot;i&quot;}, %{k: 2, v: &quot;ii&quot;}], ...&gt; :k) # NOTE: only one key function [{%{k: 1, v: &quot;one&quot;}, %{k: 1, v: &quot;i&quot;}}, {nil, %{k: 2, v: &quot;ii&quot;}}]"},{"ref":"Relate.html#select/2","title":"Relate.select/2","module":"Relate","type":"function","doc":"For each two element tuple in enumerable join, select each row specified by the cols keyword list. Each element cols should be a tuple with an initial element of :left or :right and a second element that acts as an accessor as in inner_join/4 et al. Example iex&gt; Relate.select([{{0, 1, 2}, {:a, :b, :c}}, ...&gt; {{3, 4, 5}, {:d, :e, :f}}], ...&gt; [left: 0, right: 1, left: 2]) [{0, :b, 2}, {3, :e, 5}]"}]